@@ -12,9 +12,9 @@ from agentbox.envd.api import ENVD_API_HEALTH_ROUTE, handle_envd_api_exception
 from agentbox.exceptions import SandboxException, format_request_timeout_error
 from agentbox.sandbox.main import SandboxSetup
 from agentbox.sandbox.utils import class_method_variant
-from agentbox.sandbox_sync.adb_shell.adb_shell import ADBShell
+# from agentbox.sandbox_sync.adb_shell.adb_shell import ADBShell
 from agentbox.sandbox_sync.adb_shell2.adb_shell2 import ADBShell2
-from agentbox.sandbox_sync.filesystem.filesystem import AgentBoxFilesystem as Filesystem
+from agentbox.sandbox_sync.filesystem.filesystem import Filesystem
 from agentbox.sandbox_sync.commands.command import Commands
 from agentbox.sandbox_sync.commands.pty import Pty
 from agentbox.sandbox_sync.sandbox_api import SandboxApi, SandboxInfo
@@ -75,7 +75,7 @@ class Sandbox(SandboxSetup, SandboxApi):
         return self._commands
 
     @property
-    def adb_shell(self) -> ADBShell:
+    def adb_shell(self) -> ADBShell2:
         """
         Module for adb shell in the sandbox.
         """
@@ -167,14 +167,14 @@ class Sandbox(SandboxSetup, SandboxApi):
             self._ssh_port = 22
             self._ssh_username = "debug"
             self._ssh_password = "debug"
-            self._adb_info = SandboxADB(
-                adb_auth_command="adb shell",
-                auth_password="debug",
-                connect_command="adb connect 127.0.0.1",
-                expire_time="",
-                forwarder_command="",
-                instance_no="debug_sandbox_id"
-            )
+            # self._adb_info = SandboxADB(
+            #     adb_auth_command="adb shell",
+            #     auth_password="debug",
+            #     connect_command="adb connect 127.0.0.1",
+            #     expire_time="",
+            #     forwarder_command="",
+            #     instance_no="debug_sandbox_id"
+            # )
         elif sandbox_id is not None:
             response = SandboxApi.get_info(sandbox_id=sandbox_id, api_key=api_key, domain=domain)
 
@@ -246,13 +246,13 @@ class Sandbox(SandboxSetup, SandboxApi):
             else:
                 raise Exception("Could not parse SSH connection details")
             # Get adb connection details
-            self._adb_info = SandboxApi._get_adb(
-                sandbox_id=self._sandbox_id,
-                api_key=api_key,
-                domain=domain,
-                debug=debug,
-                proxy=proxy,
-            )
+            # self._adb_info = SandboxApi._get_adb(
+            #     sandbox_id=self._sandbox_id,
+            #     api_key=api_key,
+            #     domain=domain,
+            #     debug=debug,
+            #     proxy=proxy,
+            # )
             # self._watch_commands = SSHCommands(
             #     self._ssh_host,
             #     self._ssh_port,
@@ -290,16 +290,17 @@ class Sandbox(SandboxSetup, SandboxApi):
                 self._commands,
                 self._watch_commands,
             )
-            self._adb_shell = ADBShell(
-                forwarder_command=self._adb_info.forwarder_command,
-                connect_command=self._adb_info.connect_command,
-                adb_auth_command=self._adb_info.adb_auth_command,
-                adb_auth_password=self._adb_info.auth_password,
-            )
+            # self._adb_shell = ADBShell(
+            #     forwarder_command=self._adb_info.forwarder_command,
+            #     connect_command=self._adb_info.connect_command,
+            #     adb_auth_command=self._adb_info.adb_auth_command,
+            #     adb_auth_password=self._adb_info.auth_password,
+            # )
             self._adb_shell2 = ADBShell2(
                 connection_config=self.connection_config,
                 sandbox_id=self._sandbox_id
             )
+            self._adb_shell = self._adb_shell2
         else:  
             self._envd_api_url = f"{'http' if self.connection_config.debug else 'https'}://{self.get_host(self.envd_port)}"
             self._envd_api = httpx.Client(
